@@ -21,23 +21,21 @@
 ** Author: Thorsten Kukuk <kukuk@uni-paderborn.de>
 */
 
-#ifndef _DATA_H_
-#define _DATA_H_
+#ifndef _HASH_H_
+#define _HASH_H_
 
-#define TABLESIZE 997 /*Should be a prime */
-
-typedef struct data {
+typedef struct hash {
   char *key;
   char *val;
-  struct data *next;
-} data_t;
+  struct hash *next;
+} hash_t;
 
-extern int hash_insert (data_t **table, const char *key, const char *val);
-extern int hash_free (data_t **table);
-extern char *hash_search (data_t **table, const char *key);
-extern int hash_delkey (data_t **table, const char *key);
-extern data_t **hash_malloc (void);
-extern data_t *hash_first (data_t **table);
-extern data_t *hash_next (data_t **table, const char *key);
+extern int hash_insert (hash_t **table, const char *key, const char *val);
+extern int hash_free (hash_t **table);
+extern char *hash_search (hash_t **table, const char *key);
+extern int hash_delkey (hash_t **table, const char *key);
+extern hash_t **hash_malloc (void);
+extern hash_t *hash_first (hash_t **table);
+extern hash_t *hash_next (hash_t **table, const char *key);
 
 #endif
