@@ -1,3 +1,12 @@
+/* $Id: system.h,v 1.11 1998/01/09 20:41:42 kukuk Exp $ */
+#ifndef __SYSTEM_H__
+#define __SYSTEM_H__
+
+#include "config.h"
+#ifndef HAVE_RESULTPROC_T
+typedef void *resultproc_t;
+#endif
+
 #if (defined(__sun__) || defined(sun)) && !defined(__svr4__)
 
 /* Stupid SunOS 4 doesn't have prototypes in the header files */
@@ -11,6 +20,12 @@
 #include <sys/time.h>
 #include <sys/wait.h>
 #include <sys/resource.h>
+#include <rpc/types.h>
+
+/* should be declared in /usr/include/rpc/pmap_clnt.h */
+#ifdef HAVE_RESULTPROC_T
+typedef bool_t (*resultproc_t) (void *, void *);
+#endif
 
 extern int fprintf(FILE *, const char *, ...);
 extern int fscanf(FILE *, const char *, ...);
@@ -43,6 +58,7 @@ extern pid_t wait4(pid_t pid, int *status, int options, struct rusage *rusage);
 #endif
 
 #if (defined(__sun__) || defined(sun)) && defined(__svr4__)
+/* Solaris 2.x */
 
 #define __EXTENSIONS__
 #define NEED_SVCSOC_H
@@ -74,38 +90,34 @@ extern void svcerr_systemerr();
 #endif
 
 /* Needed for non-ANSI prototypes */
+#ifndef _SVID_SOURCE
 #define _SVID_SOURCE
+#endif
 
 /* Needed for gethostname() */
+#ifndef _BSD_SOURCE
 #define _BSD_SOURCE
-#define __USE_GNU
-
-
-/* xdr_domainname in Linux libc 5.x.x is really broken, so
-** all functions in libc, which call them, too.
-** But why is it broken with libc 5.x.x and NYS support, too ??
-*/
-#define HAVE_BROKEN_LINUX_LIBC 1 
-
-/*
-** Linux has a _dns_gethostbyname in a libc with NYS support,
-** or in dns_hosts.c
-*/
-extern struct hostent *_dns_gethostbyname(const char *);
-extern struct hostent *_dns_gethostbyaddr(const char *, int, int);
+#endif
 
 extern int snprintf (char *, unsigned int, const char *, ...);
 
+#endif /* linux */
+
+#if !defined(HAVE_RES_GETHOSTBYNAME)
+#if defined(HAVE__DNS_GETHOSTBYNAME) || defined(linux)
+#define res_gethostbyname _dns_gethostbyname
+extern struct hostent *_dns_gethostbyname(const char *);
+#define res_gethostbyaddr _dns_gethostbyaddr
+extern struct hostent *_dns_gethostbyaddr(const char *, int, int);
 #else
-
-#if !defined(HAVE__DNS_GETHOSTBYNAME)
-/*
-** Only Linux has a _dns_gethostbyname so far as I know, 
-** for other OS, we must use the libc or resolv+ version
-*/
-#define _dns_gethostbyname gethostbyname
-#define _dns_gethostbyaddr gethostbyaddr
-
+/* !defined(HAVE_RES_GETHOSTBYNAME) && !defined(HAVE__DNS_GETHOSTBYNAME) */
+#define res_gethostbyname gethostbyname
+#define res_gethostbyaddr gethostbyaddr
+#endif
+#else
+/* defined(HAVE_RES_GETHOSTBYNAME) */
+extern struct hostent *res_gethostbyname(const char *);
+extern struct hostent *res_gethostbyaddr(const char *, int, int);
 #endif
 
 #endif
