@@ -1,5 +1,5 @@
 /*
-** Copyright (c) 1996, 1997 Thorsten Kukuk 
+** Copyright (c) 1996, 1997, 1998 Thorsten Kukuk
 **
 ** This file is part of the NYS YP Server.
 **
@@ -12,7 +12,7 @@
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ** General Public License for more details.
-** 
+**
 ** You should have received a copy of the GNU General Public
 ** License along with the NYS YP Server; see the file COPYING.  If
 ** not, write to the Free Software Foundation, Inc., 675 Mass Ave,
@@ -22,7 +22,7 @@
 */
 
 #ifndef LINT
-static const char rcsid[] = "$Id: yppush.c,v 1.8 1997/01/29 19:16:29 kukuk Exp $";
+static const char rcsid[] = "$Id: yppush.c,v 1.12 1998/01/09 20:41:43 kukuk Exp $";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -102,7 +102,7 @@ extern int _rpc_dtablesize(void);
 int _rpc_dtablesize()
 {
         static int size;
-        
+
         if (size == 0) {
                 size = getdtablesize();
         }
@@ -128,9 +128,9 @@ int _rpc_dtablesize()
 }
 #endif
 
-static char *yppush_err_string(enum yppush_status status) 
+static char *yppush_err_string(enum yppush_status status)
 {
-  switch(status) 
+  switch(status)
     {
     case YPPUSH_SUCC:      return "Success";
     case YPPUSH_AGE:       return "Master's version not newer";
@@ -168,12 +168,12 @@ yppushresp_xfr *yppushproc_xfrresp_1_svc(void *req, struct svc_req * rqstp)
   struct sockaddr_in *sin;
   char *h;
   struct hostent *hp;
-  
+
   if(verbose_flag > 1)
     yp_msg("yppushproc_xfrresp_1_svc\n");
 
   sin = svc_getcaller(rqstp->rq_xprt);
-  
+
   hp = gethostbyaddr((char *) &sin->sin_addr.s_addr,
                      sizeof (sin->sin_addr.s_addr), AF_INET);
   h = (hp && hp->h_name) ? hp->h_name : inet_ntoa(sin->sin_addr);
@@ -200,41 +200,41 @@ void yppush_xfrrespprog_1( struct svc_req *rqstp, SVCXPRT *transp)
   static char *result;
   static bool_t (*xdr_argument)(XDR *, void *), (*xdr_result)(XDR *, void *);
   static char *(*local)( void *, struct svc_req *);
- 
+
   if(verbose_flag > 1)
     yp_msg("yppush_xfrrespprog_1\n");
- 
-  switch (rqstp->rq_proc) 
+
+  switch (rqstp->rq_proc)
     {
     case YPPUSHPROC_NULL:
       xdr_argument = (bool_t (*)(XDR *, void *))xdr_void;
       xdr_result = (bool_t (*)(XDR *, void *))xdr_void;
       local = (char *(*)( void *, struct svc_req *)) yppushproc_null_1_svc;
       break;
-      
+
     case YPPUSHPROC_XFRRESP:
       xdr_argument = (bool_t (*) (XDR *, void *))xdr_yppushresp_xfr;
       xdr_result = (bool_t (*)(XDR *, void *))xdr_void;
       local = (char *(*)( void *, struct svc_req *)) yppushproc_xfrresp_1_svc;
       break;
-      
+
     default:
       svcerr_noproc(transp);
       exit(1);
     }
   memset(&argument, '\0',  sizeof(argument));
-  if (!svc_getargs(transp, xdr_argument, (void *) &argument)) 
+  if (!svc_getargs(transp, (xdrproc_t) xdr_argument, (void *) &argument))
     {
       svcerr_decode(transp);
       exit(1);
     }
   result = (*local)(&argument, rqstp);
-  if (result != NULL && 
-      !svc_sendreply(transp, (xdrproc_t) xdr_result, result)) 
+  if (result != NULL &&
+      !svc_sendreply(transp, (xdrproc_t) xdr_result, result))
     {
       svcerr_systemerr(transp);
     }
-  if (!svc_freeargs(transp, xdr_argument, (void *) &argument)) 
+  if (!svc_freeargs(transp, (xdrproc_t) xdr_argument, (void *) &argument))
     {
       yp_msg("unable to free arguments\n");
       exit(1);
@@ -250,21 +250,21 @@ static void yppush_svc_run(char *target)
   int readfds;
 #endif /* def FD_SETSIZE */
   struct timeval tr, tb;
-  
+
   tb.tv_sec=timeout; tb.tv_usec=0;
   tr = tb;
 
-  for (;;) 
+  for (;;)
     {
 #ifdef FD_SETSIZE
       readfds = svc_fdset;
 #else
       readfds = svc_fds;
 #endif /* def FD_SETSIZE */
-      switch (select(_rpc_dtablesize(), &readfds, (void *)0, (void *)0, &tr)) 
+      switch (select(_rpc_dtablesize(), &readfds, (void *)0, (void *)0, &tr))
 	{
 	case -1:
-	  if (errno == EINTR) 
+	  if (errno == EINTR)
 	    {
 	      tr = tb; /* Read the Linux select.2 manpage ! */
 	      continue;
@@ -288,14 +288,14 @@ static int hostcmp(char *h1, char *h2)
 {
   char buf1[MAXHOSTNAMELEN+1], buf2[MAXHOSTNAMELEN+1];
   char *p, *s;
-  
+
   strncpy(buf1, h1, sizeof(buf1));
   strncpy(buf2, h2, sizeof(buf2));
   s = strchr(buf1, '.');
   p = strchr(buf2, '.');
   if (s && !p) *s = 0;
   if (p && !s) *p = 0;
-  
+
   return strcmp(buf1, buf2);
 }
 
@@ -306,7 +306,7 @@ static char *get_dbm_entry(char *key)
   datum dkey,dval;
   GDBM_FILE dbm;
 
-#if defined(HAVE_SNPRINTF)  
+#if defined(HAVE_SNPRINTF)
   if(snprintf(mappath, MAXPATHLEN, "%s/%s/%s", YPMAPDIR, DomainName, current_map)==MAXPATHLEN)
 #else
   if(strlen(YPMAPDIR)+strlen(DomainName)+strlen(current_map)+3 < MAXPATHLEN)
@@ -318,11 +318,11 @@ static char *get_dbm_entry(char *key)
       exit(-1);
     }
 
-  if ((dbm=gdbm_open(mappath, 0, GDBM_READER, 0600, NULL))==NULL) 
+  if ((dbm=gdbm_open(mappath, 0, GDBM_READER, 0600, NULL))==NULL)
     {
       yp_msg("YPPUSH: Cannot open %s\n", mappath);
       exit(-1);
-    }	
+    }
 
   dkey.dptr=key; dkey.dsize=strlen(dkey.dptr);
   dval=gdbm_fetch(dbm,dkey);
@@ -334,16 +334,16 @@ static char *get_dbm_entry(char *key)
       val = malloc(dval.dsize+1);
       strncpy(val,dval.dptr,dval.dsize);
       val[dval.dsize] = 0;
-      
+
       return val;
     }
-} 
+}
 
 static u_int getordernum( void)
 {
   char *val;
-  u_int i; 
-  
+  u_int i;
+
   val = get_dbm_entry("YP_LAST_MODIFIED");
 
   if (val==NULL)
@@ -353,16 +353,16 @@ static u_int getordernum( void)
       return -1;
     }
 
-  for (i=0; i<strlen(val); i++) 
+  for (i=0; i<strlen(val); i++)
     {
-      if (!isdigit(val[i])) 
+      if (!isdigit(val[i]))
 	{
 	  yp_msg("YPPUSH: %s: Invalid order number '%s'\n",
 		 current_map, val);
 	  return -1;
 	}
     }
-  
+
   i = atoi(val);
 
   free(val);
@@ -385,13 +385,13 @@ static int add_slave_server(int status, const char *key, int keylen,
 {
   char host[YPMAXPEER+2];
   struct hostlist *tmp;
-  
+
   if(verbose_flag>1)
     yp_msg("add_slave_server: Key=%.*s, Val=%.*s, status=%d\n",keylen,key,vallen,val,status);
-  
-  if (status!=YP_TRUE) 
+
+  if (status!=YP_TRUE)
     return status;
-  
+
 #if defined(HAVE_SNPRINTF)
   if(snprintf(host,YPMAXPEER,"%.*s", vallen, val)==YPMAXPEER)
 #else
@@ -405,14 +405,14 @@ static int add_slave_server(int status, const char *key, int keylen,
     }
 
   /* Do not add ourself! */
-  if (hostcmp(local_hostname, host) == 0) 
+  if (hostcmp(local_hostname, host) == 0)
     {
-      if (verbose_flag > 1) 
+      if (verbose_flag > 1)
 	yp_msg("add_slave_server: skipping %s\n", host);
       return 0;
     }
-  
-  if ((tmp = (struct hostlist *)malloc(sizeof(struct hostlist))) == NULL) 
+
+  if ((tmp = (struct hostlist *)malloc(sizeof(struct hostlist))) == NULL)
     {
       yp_msg("malloc() failed: %s", strerror(errno));
       return -1;
@@ -433,7 +433,7 @@ static void child_sig_int(int sig)
 
 static int yppush_foreach(const char *host)
 {
-  SVCXPRT *CallbackXprt;  
+  SVCXPRT *CallbackXprt;
   CLIENT *PushClient=NULL;
   struct ypreq_xfr req;
   struct timeval tv={10,0};
@@ -451,12 +451,12 @@ static int yppush_foreach(const char *host)
   sa.sa_handler=child_sig_int;
   sigemptyset(&sa.sa_mask);
 #if defined(linux) || (defined(sun) && defined(__srv4__))
-  sa.sa_flags=SA_NOMASK; 
+  sa.sa_flags=SA_NOMASK;
   /* Do  not  prevent  the  signal   from   being
      received from within its own signal handler. */
 #endif
   sigaction(SIGINT, &sa, NULL);
-  
+
 #if defined(HAVE_SNPRINTF)
   if(snprintf(server,YPMAXPEER,"%s", host)==YPMAXPEER)
 #else
@@ -470,7 +470,7 @@ static int yppush_foreach(const char *host)
     }
 
   PushClient=clnt_create(server, YPPROG, YPVERS, "tcp");
-  if (PushClient==NULL) 
+  if (PushClient==NULL)
     {
       yp_msg("%s",host);
       clnt_pcreateerror("");
@@ -479,19 +479,19 @@ static int yppush_foreach(const char *host)
 
   sock=RPC_ANYSOCK;
   CallbackXprt=svcudp_create(sock);
-  if (CallbackXprt==NULL) 
+  if (CallbackXprt==NULL)
     {
       yp_msg("YPPUSH: Cannot create callback transport.\n");
       return 1;
     }
-  for (CallbackProg=0x40000000; CallbackProg<0x5fffffff; CallbackProg++) 
+  for (CallbackProg=0x40000000; CallbackProg<0x5fffffff; CallbackProg++)
     {
       if (svc_register(CallbackXprt, CallbackProg, 1,
 		       yppush_xfrrespprog_1, IPPROTO_UDP))
 	break;
     }
-  
-  switch (transid=fork()) 
+
+  switch (transid=fork())
     {
     case -1:
       perror("Cannot fork");
@@ -509,14 +509,14 @@ static int yppush_foreach(const char *host)
       req.transid=transid;
       req.prog=CallbackProg;
       req.port=CallbackXprt->xp_port;
-      
+
       if (verbose_flag)
 	{
 	  yp_msg("%s has been called.\n",server);
 	  if (verbose_flag>1)
 	    {
 	      yp_msg("\t->target: %s\n",server);
-	      yp_msg("\t->domain: %s\n",req.map_parms.domain);      
+	      yp_msg("\t->domain: %s\n",req.map_parms.domain);
 	      yp_msg("\t->map: %s\n",req.map_parms.map);
 	      yp_msg("\t->tarnsid: %d\n",req.transid);
 	      yp_msg("\t->prog: %d\n",req.prog);
@@ -524,10 +524,10 @@ static int yppush_foreach(const char *host)
 	      yp_msg("\t->ordernum: %d\n",req.map_parms.ordernum);
 	    }
 	}
-      
-      if(clnt_call(PushClient, YPPROC_XFR, (xdrproc_t) xdr_ypreq_xfr,  
-		   (void *) &req, (xdrproc_t) xdr_void, NULL, tv) 
-	 != RPC_SUCCESS) 
+
+      if(clnt_call(PushClient, YPPROC_XFR, (xdrproc_t) xdr_ypreq_xfr,
+		   (void *) &req, (xdrproc_t) xdr_void, NULL, tv)
+	 != RPC_SUCCESS)
 	{
 	  clnt_perror(PushClient, "YPPUSH: Cannot call YPPROC_XFR");
 	  kill(transid, SIGTERM);
@@ -539,7 +539,7 @@ static int yppush_foreach(const char *host)
 #endif
       svc_unregister(CallbackProg, 1);
       CallbackProg=0;
-      if (PushClient!=NULL) 
+      if (PushClient!=NULL)
 	{
 	  clnt_destroy(PushClient);
 	  PushClient=NULL;
@@ -548,15 +548,15 @@ static int yppush_foreach(const char *host)
 
   return 0;
 }
-	
-static void 
+
+static void
 sig_child (int sig)
 {
    int status;
 
-#ifdef HAVE_WAIT3   
+#ifdef HAVE_WAIT3
    while (wait3(&status, WNOHANG, NULL) > 0)
-#else 
+#else
    while (waitpid(-1, &status, WNOHANG) > 0)
 #endif
      {
@@ -566,7 +566,7 @@ sig_child (int sig)
      }
 }
 
-static inline void 
+static inline void
 Usage (int exit_code)
 {
   yp_msg("Usage: yppush [-d domain] [-t timeout] [-p #] [-h host] [-v] mapname ...\n");
@@ -581,17 +581,17 @@ int main(int argc, char **argv)
   struct ypall_callback f;
   enum ypstat y;
   struct sigaction a;
-  
+
   a.sa_handler=sig_child;
   sigemptyset(&a.sa_mask);
 #if defined(linux) || (defined(sun) && defined(__srv4__))
-  a.sa_flags=SA_NOMASK; 
+  a.sa_flags=SA_NOMASK;
   /* Do  not  prevent  the  signal   from   being
      received from within its own signal handler. */
 #endif
   sigaction(SIGCHLD, &a, NULL);
-  
-  while(1) 
+
+  while(1)
     {
       int c;
       int option_index = 0;
@@ -606,10 +606,10 @@ int main(int argc, char **argv)
 	{"timeout", required_argument, NULL, 't'},
         {NULL, 0, NULL, '\0'}
       };
-      
+
       c=getopt_long(argc, argv, "d:vh:ut:p:j:",long_options, &option_index);
       if (c==EOF) break;
-      switch (c) 
+      switch (c)
 	{
 	case 'd':
 	  DomainName=optarg;
@@ -626,7 +626,7 @@ int main(int argc, char **argv)
 	  break;
 	case 'h':
 	  /* we can handle multiple hosts */
-	  if ((tmp = (struct hostlist *)malloc(sizeof(struct hostlist))) == NULL) 
+	  if ((tmp = (struct hostlist *)malloc(sizeof(struct hostlist))) == NULL)
 	    {
 	      yp_msg("malloc() failed: %s", strerror(errno));
 	      return 1;
@@ -647,19 +647,19 @@ int main(int argc, char **argv)
     }
   argc-=optind;
   argv+=optind;
-  
+
   if (argc<1) Usage(1);
-  
-  if (DomainName==NULL) 
+
+  if (DomainName==NULL)
     {
-      if (yp_get_default_domain(&DomainName)!=0) 
+      if (yp_get_default_domain(&DomainName)!=0)
 	{
 	  yp_msg("YPPUSH: Cannot get default domain\n");
 	  return 1;
 	}
     }
-  
-  if (gethostname(local_hostname, MAXHOSTNAMELEN)!=0) 
+
+  if (gethostname(local_hostname, MAXHOSTNAMELEN)!=0)
     {
       perror("YPPUSH: gethostname");
       yp_msg("YPPUSH: Cannot determine local hostname\n");
@@ -674,13 +674,13 @@ int main(int argc, char **argv)
 #else
       y = yp_all (DomainName, "ypservers", &f);
 #endif
-      if (y && y!=YP_NOMORE) 
+      if (y && y!=YP_NOMORE)
 	{
 	  yp_msg("Could not read ypservers: %d %s\n",
 		 y, yperr_string(y));
 	}
     }
-  
+
   while(*argv)
     {
       char *val;
@@ -723,7 +723,7 @@ int main(int argc, char **argv)
 	    }
 	  tmp = tmp->next;
 	}
-      while(children != 0) 
+      while(children != 0)
 	{
 	  sleep(10);
 	  if(verbose_flag>1)
