@@ -1,14 +1,14 @@
 #ifndef __YPSERV_H__
 #define __YPSERV_H__
 
-/* 
-** $Id: ypserv.h,v 1.0.4.1 1996/07/14 15:10:45 kukuk Exp $ 
+/*
+** $Id: ypserv.h,v 1.5 1997/12/30 18:08:05 kukuk Exp $
 */
 
 #include <rpc/rpc.h>
 
 /* Struct for ypserv.conf options */
-typedef struct conffile 
+typedef struct conffile
 {
   struct in_addr netmask;
   struct in_addr network;
@@ -21,20 +21,25 @@ typedef struct conffile
 
 extern char *progname;      	/* ypserv.c */
 extern char *path_ypdb;		/* ypserv.c */
-extern int debug_flag;		/* ypserv.c */
-extern int dns_flag;		/* ypserv.c */
-extern int sunos_kludge_flag;   /* ypserv.c */
-extern int tryresolve_flag;     /* ypserv.c */
-extern int children;		/* server.c */
+extern int debug_flag;		/* ypserv.c || ypxfrd.c */
+extern int dns_flag;		/* ypserv.c || ypxfrd.c */
+extern int sunos_kludge_flag;   /* ypserv.c || ypxfrd.c */
+extern int children;		/* server.c || ypxfrd.c */
+extern int forked;		/* server.c || ypxfrd.c */
+extern int xfr_check_port;	/* server.c || ypxfrd.c */
 
-/* 
-** returns 1, if secure, else 0 
+/*
+** returns 1, if secure, else 0 or -1, if domain is not valid
+*/
+extern int is_valid_host(struct svc_req *rqstp, const char *map,
+			 const char *domain);
+/*
+** returns 1, if secure, else 0
 */
-extern int is_valid_host(struct svc_req *rqstp, const char *map);
 extern int is_valid_domain(const char *domain);
 
-/* 
-** load/reload the YPMAPDIR/securenets file 
+/*
+** load/reload the YPMAPDIR/securenets file
 */
 extern void load_securenets(void);
 extern void load_config(void);
@@ -50,6 +55,7 @@ extern void ypserv_svc_run(void);
 #define SEC_NONE 0
 #define SEC_DENY 1
 #define SEC_PORT 2
+#define SEC_DES  3
 
 /* Mangle field: */
 #define MANGLE_NO 0
